# Table of Contents

- [automation-examples-use-cases-by-triggers](<./automation-examples-use-cases-by-triggers.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Automations Best Practices: Use Cases by Triggers](<./Automations-Best-Practices-Use-Cases-by-Triggers.md>)
  - [Overview](<./Automations-Best-Practices-Use-Cases-by-Triggers/Overview.md>)
  - [Creating Subscriptions for Specific Users on Newly Created Fact Sheets](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-Subscriptions-for-Specific-Users-on-Newly-Created-Fact-Sheets.md>)
  - [Creating Subscriptions for Fact Sheet Creators on Newly Created Fact Sheets](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-Subscriptions-for-Fact-Sheet-Creators-on-Newly-Created-Fact-Sheets.md>)
  - [Creating an Action Item for Fact Sheet Creators on Newly Created Fact Sheets](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-for-Fact-Sheet-Creators-on-Newly-Created-Fact-Sheets.md>)
  - [Adding Tags or Setting Single-Select Field Values on Newly Created Fact Sheets](<./Automations-Best-Practices-Use-Cases-by-Triggers/Adding-Tags-or-Setting-Single-Select-Field-Values-on-Newly-Created-Fact-Sheets.md>)
  - [Changing a Field Value Based on Another Field Value](<./Automations-Best-Practices-Use-Cases-by-Triggers/Changing-a-Field-Value-Based-on-Another-Field-Value.md>)
  - [Creating an Action Item on a Field Change](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-on-a-Field-Change.md>)
  - [Assigning an Action Item to Subscriptions (Fixed Users) on Lifecycle Phase Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Assigning-an-Action-Item-to-Subscriptions-Fixed-Users-on-Lifecycle-Phase-Changes.md>)
  - [Adding or Removing a Tag on Lifecycle Phase Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Adding-or-Removing-a-Tag-on-Lifecycle-Phase-Changes.md>)
  - [Setting a Single-Select Field on Lifecycle Phase Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Setting-a-Single-Select-Field-on-Lifecycle-Phase-Changes.md>)
  - [Assigning an Action Item to Subscriptions on Quality State Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Assigning-an-Action-Item-to-Subscriptions-on-Quality-State-Changes.md>)
  - [Assigning an Action Item to Specific Users on Quality State Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Assigning-an-Action-Item-to-Specific-Users-on-Quality-State-Changes.md>)
  - [Adding a Tag or Setting a Single-Select Field Value on Quality Seal Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Adding-a-Tag-or-Setting-a-Single-Select-Field-Value-on-Quality-Seal-Changes.md>)
  - [Creating an Action Item for Subscriptions on Tag Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-for-Subscriptions-on-Tag-Addition-or-Removal.md>)
  - [Creating an Action Item for Specific Users on Tag Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-for-Specific-Users-on-Tag-Addition-or-Removal.md>)
  - [Adding a Subscription on Tag Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Adding-a-Subscription-on-Tag-Addition-or-Removal.md>)
  - [Conditional Tagging](<./Automations-Best-Practices-Use-Cases-by-Triggers/Conditional-Tagging.md>)
  - [Creating an Action Item for Subscriptions on Subscription Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-for-Subscriptions-on-Subscription-Addition-or-Removal.md>)
  - [Creating an Action Item for Fixed Users on Subscription Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Creating-an-Action-Item-for-Fixed-Users-on-Subscription-Addition-or-Removal.md>)
  - [Adding a Subscription on Subscription Addition or Removal](<./Automations-Best-Practices-Use-Cases-by-Triggers/Adding-a-Subscription-on-Subscription-Addition-or-Removal.md>)
  - [Tagging on Subscription Changes](<./Automations-Best-Practices-Use-Cases-by-Triggers/Tagging-on-Subscription-Changes.md>)
  - [Was this page helpful?](<./Automations-Best-Practices-Use-Cases-by-Triggers/Was-this-page-helpful.md>)
